@@ -4,7 +4,7 @@ use crate::prf::*;
 
 use anyhow::Result;
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 pub struct CipherSuiteTlsPskWithAes128GcmSha256 {
     gcm: Option<CryptoGcm>,
 }
@@ -15,12 +15,6 @@ impl CipherSuiteTlsPskWithAes128GcmSha256 {
     const PRF_IV_LEN: usize = 4;
 }
 
-impl Default for CipherSuiteTlsPskWithAes128GcmSha256 {
-    fn default() -> Self {
-        CipherSuiteTlsPskWithAes128GcmSha256 { gcm: None }
-    }
-}
-
 impl CipherSuite for CipherSuiteTlsPskWithAes128GcmSha256 {
     fn to_string(&self) -> String {
         "TLS_PSK_WITH_AES_128_GCM_SHA256".to_owned()
